<?php

namespace elggBook\elggBookTools;

use ElggEntity;
use ElggIcon;
use ElggUser;
use UFCOE\Elgg\SiteUrl;

/**HYPEDISCOVERY
 * Sniff a URL for a known entity GUID
 *
 * @param string $url URL
 * @return integer|false
 */
function get_guid_from_url($url) {

	$site_url = new SiteUrl(elgg_get_site_url());

	$path = $site_url->getSitePath($url);
	if (!$path) {
		return false;
	}

	$guid = $path->getGuid();
	if ($guid) {
		return $guid;
	}

	$username = $path->getUsername();
	if ($username) {
		$user = get_user_by_username($username);
		if ($user) {
			return $user->guid;
		}
	}

	$container_guid = $path->getContainerGuid();
	if ($container_guid) {
		return $container_guid;
	}

	return false;
}

/**
 * Get entity from URL
 * 
 * @param string $url URL
 * @return ElggEntity|false
 */
function get_entity_from_url($url) {
	$guid = get_guid_from_url($url);
	$entity = get_entity($guid);
	return $entity ?: elgg_get_site_entity();
}

/**
 * List discovery providers
 * @return array
 */
function get_discovery_providers() {
	$providers = elgg_get_plugin_setting('providers', 'hypeDiscovery');
	return ($providers) ? unserialize($providers) : [];
}

