<?php
/**
 * Elgg hypeWall Extension
 * @package elggBook
 */

if (!elgg_is_logged_in()) {
	return;
}

if (!elgg_in_context('activity') && !elgg_in_context('wall')) {
	return;
}

$owner = elgg_get_page_owner_entity();

$user = elgg_get_logged_in_user_entity();
$page_owner = elgg_get_page_owner_entity();

// Make sure user can write to container before displaying the form
if (elgg_instanceof($page_owner) && !$page_owner->canWriteToContainer($user->guid, 'object', $subtype)) {
	return;
}

/********************************************
************* hypeWall Extensions *************
********************************************/

$forms = '';

// add status support through thewire plugin
if ($owner instanceof ElggUser) {
    if (elgg_is_active_plugin('thewire') && elgg_get_plugin_setting('thewire', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_register_menu_item('wall-filter', array(
		'name' => 'thewire',
		'text' => elgg_view_icon('microphone', ['class' => 'wall-icon wall-icon-thewire']),
		'title' => elgg_echo('wall:thewire'),
		'href' => '#wall-form-thewire',
		'link_class' => 'wall-tab',
		'selected' => ($default == 'thewire'),
		'priority' => 100
	));
	$class = 'wall-form';
	if ($default !== 'thewire') {
		$class .= ' hidden';
	}
	$forms = elgg_view_form('thewire/add', array(
		'id' => 'wall-form-thewire',
		'class' => $class,
			), $vars);
    }
}
if ($owner instanceof ElggGroup) {
	if (elgg_is_active_plugin('discussions') && elgg_get_plugin_setting('discussions', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_register_menu_item('wall-filter', array(
		'name' => 'discussions',
		'text' => elgg_view_icon('stack-exchange', ['class' => 'wall-icon wall-icon-discussions']),
		'title' => elgg_echo('wall:discussions'),
		'href' => '#wall-form-discussions',
		'link_class' => 'wall-tab',
		'selected' => ($default == 'discussions'),
		'priority' => 100
	));
	$class = 'wall-form';
	if ($default !== 'discussions') {
		$class .= ' hidden';
	}
	$forms = elgg_view_form('discussion/save', array(
		'id' => 'wall-form-discussions',
		'class' => $class,
			), $vars);
    }
}
// add video support through videolist plugin
if (elgg_is_active_plugin('videolist') && elgg_get_plugin_setting('videolist', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_register_menu_item('wall-filter', array(
		'name' => 'videolist',
		'text' => elgg_view_icon('video-camera', ['class' => 'wall-icon wall-icon-video']),
		'title' => elgg_echo('wall:videolist'),
		'href' => '#wall-form-videolist',
		'link_class' => 'wall-tab',
		'selected' => ($default == 'videolist'),
		'priority' => 300
	));
	$class = 'wall-form';
	if ($default !== 'videolist') {
		$class .= ' hidden';
	}
	$forms .= elgg_view_form('videolist/edit', array(
		'id' => 'wall-form-videolist',
		'class' => $class,
		'enctype' => 'multipart/form-data',
	), $vars);
}

// add polls support through poll plugin
if (elgg_is_active_plugin('poll') && elgg_get_plugin_setting('poll', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	$poll_site_access = elgg_get_plugin_setting('site_access', 'poll');
	if ($poll_site_access != 'admins' || elgg_is_admin_logged_in()) {
			
		elgg_register_menu_item('wall-filter', array(
			'name' => 'poll',
			'text' => elgg_view_icon('check-square', ['class' => 'wall-icon wall-icon-poll']),
			'title' => elgg_echo('wall:poll'),
			'href' => '#wall-form-poll',
			'link_class' => 'wall-tab',
			'selected' => ($default == 'poll'),
			'priority' => 350
		));
		$class = 'wall-form';
		if ($default !== 'poll') {
			$class .= ' hidden';
		}
		$forms .= elgg_view_form('poll/edit', array(
			'id' => 'wall-form-poll',
			'class' => $class,
			'enctype' => 'multipart/form-data',
		), $vars);
	}
}

// add blog support through blog plugin
if (elgg_is_active_plugin('blog') && elgg_get_plugin_setting('blog', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_load_library('elgg:blog');
	elgg_register_menu_item('wall-filter', array(
		'name' => 'blog',
		'text' => elgg_view_icon('bold', ['class' => 'wall-icon wall-icon-blog']),
		'title' => elgg_echo('wall:blog'),
		'href' => '#wall-form-blog',
		'link_class' => 'wall-tab',
		'selected' => ($default == 'blog'),
		'priority' => 450
	));
	$class = 'wall-form';
	if ($default !== 'blog') {
		$class .= ' hidden';
	}
	$body_vars = blog_prepare_form_vars(null);
	$forms .= elgg_view_form('blog/save', array(
		'id' => 'wall-form-blog',
		'class' => $class,
		'title' => '',
		'enctype' => 'multipart/form-data',
	), $body_vars);
}

// add market support through market plugin
if (elgg_is_active_plugin('market') && elgg_get_plugin_setting('market', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_register_menu_item('wall-filter', array(
		'name' => 'market',
		'text' => elgg_view_icon('shopping-cart', ['class' => 'wall-icon wall-icon-market']),
		'title' => elgg_echo('wall:market'),
		'href' => '#wall-form-market',
		'link_class' => 'wall-tab',
		'selected' => ($default == 'market'),
		'priority' => 500
	));
	$class = 'wall-form';
	if ($default !== 'market') {
		$class .= ' hidden';
	}
	$forms .= elgg_view_form('market/save', array(
		'id' => 'wall-form-market',
		'class' => $class,
		'enctype' => 'multipart/form-data',
	), $vars);
}

// add events support through event_manager plugin
if (elgg_is_active_plugin('event_manager') && elgg_get_plugin_setting('event_manager', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	$who_create_site_events = elgg_get_plugin_setting('who_create_site_events', 'event_manager');
	if ($who_create_site_events != 'admin_only' || elgg_is_admin_logged_in()) {
		elgg_register_menu_item('wall-filter', array(
			'name' => 'event',
			'text' => elgg_view_icon('calendar', ['class' => 'wall-icon wall-icon-event']),
			'title' => elgg_echo('wall:event'),
			'href' => '#wall-form-event',
			'link_class' => 'wall-tab',
			'selected' => ($default == 'event'),
			'priority' => 400
		));
		$class = 'wall-form';
		if ($default !== 'event') {
			$class .= ' hidden';
		}	
		$forms .= elgg_view_form('event_manager/event/edit', array(
			'id' => 'wall-form-event',
			'class' => $class,
			'enctype' => 'multipart/form-data',
		), $vars);
	}
}

// add photo support through hypeGallery plugin
if (elgg_is_active_plugin('hypeGallery') && elgg_get_plugin_setting('hypeGallery', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_register_menu_item('wall-filter', array(
		'name' => 'hjalbum',
		'text' => elgg_view_icon('image', ['class' => 'wall-icon wall-icon-hjalbum']),
		'title' => elgg_echo('wall:hjalbum'),
		'href' => '#wall-form-hjalbum',
		'selected' => ($default == 'hjalbum'),
		'link_class' => 'wall-tab',
		'priority' => 250
	));
	$class = 'wall-form';
	if ($default !== 'hjalbum') {
		$class .= ' hidden elgg-form-edit-object-hjalbum elgg-form';
	}
	$forms .= elgg_view_form ('edit/object/hjalbum', array(
		'id' => 'wall-form-hjalbum',
		'class' => $class,
		'enctype' => 'multipart/form-data',
	), $vars);
}

// add video support through Izap video plugin
if (elgg_is_active_plugin('izap_videos') && elgg_get_plugin_setting('izap_videos', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_register_menu_item('wall-filter', array(
		'name' => 'videos',
		'text' => elgg_view_icon('film', ['class' => 'wall-icon wall-icon-videos']),
		'title' => elgg_echo('wall:videos'),
		'href' => '#wall-form-videos',
		'link_class' => 'wall-tab',
		'selected' => ($default == 'videos'),
		'priority' => 300
	));
	$class = 'wall-form';
	if ($default !== 'videos') {
		$class .= ' hidden';
	}
	$forms .= elgg_view_form('izap_videos/addEdit', array(
		'id' => 'wall-form-videos',
		'class' => $class,
		'enctype' => 'multipart/form-data',
	), $vars);
}

// add album support through Tidypics plugin
if (elgg_is_active_plugin('tidypics') && elgg_get_plugin_setting('tidypics', HYPEWALL_EXTENSION_ID)==HYPEWALL_EXTENSION_GENERAL_YES) {
	elgg_load_js('tidypics');
	elgg_load_js('lightbox');
	elgg_register_menu_item('wall-filter', array(
		'name' => 'tidypics',
		'text' => elgg_view_icon('image', ['class' => 'wall-icon wall-icon-tidypics']),
		'title' => elgg_echo('wall:tidypics'),
		'href' => "ajax/view/photos/selectalbum/?owner_guid=" . elgg_get_logged_in_user_guid,
		'link_class' => 'elgg-lightbox',
		'priority' => 250,
	));
}

echo $forms;
